@@ -105,7 +105,7 @@ def separateWaveformTypes(file, headertype):
 		#at this stage the headers and waveforms have not been modified, just sent somewhere
 		eventType = header['event type']
 		tempWaveform = bf.doAnd(file[curloc+headerlength:curloc+length+headerlength])
-		checksum = bf.Fletcher32(tempWaveform)
+		checksum = bf.Fletcher32(tempWaveform.view(np.uint16))
 		if eventType == 0:
 			singles.append(file[curloc:curloc+length+headerlength])
 			singlesChecksums.append(checksum)
